# This file is part of ROBOTGAME
#
# ROBOTGAME is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# ROBOTGAME is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# ROBOTGAME.  If not, see <http://www.gnu.org/licenses/>.
#
# ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' '
#
#                          boulder.py
#                     --------------------
#       date created : Wed Aug 8 2012
#          copyright : (C) 2012 Sakse Dalum
#      maintained by : Sakse Dalum <don_s@hongabar.org>

"""
A rolling boulder.
"""

import pygame

import worldobject
import block
import player

class Boulder(worldobject.WorldObject):
    def __init__(self, level, x, y, direction=(1, 0),
                 movable=True, rolling=False):
        self.__dict__.update(locals())
        worldobject.WorldObject.__init__(self, level, x, y, direction=direction,
                                         movable=movable, speed=4)

        self.falling = False

        self.anim = 'boulder_right'
        self.frame = 0
        self.anim_speed = 60

        self.ignore_list.append(player.Player)

    def fall(self, setting):
        if setting and not self.falling:
            self.frame = 0
            self.falling = True

    def activate(self, setting):
        self.rolling = True

    def reset_pos(self):
        worldobject.WorldObject.reset_pos(self)
        self.frame = 0
        self.rolling = False
        self.falling = False

    def update(self, e, t, dt):
        # Update the animation
        if self.rolling:
            self.frame = ((self.frame + self.anim_speed * dt) %
                          len(self.level.imgs[self.anim]))
        if self.falling:
            self.frame = min(self.frame + self.anim_speed * dt,
                             len(self.level.imgs[self.anim]) - 1)

        if self.falling:
            self.anim = 'boulder_falling'
            if self.frame == len(self.level.imgs[self.anim]) - 1:
                self.reset_pos()
        elif self.direction == (1, 0):
            self.anim = 'boulder_right'
        elif self.direction == (0, 1):
            self.anim = 'boulder_down'
        elif self.direction == (-1, 0):
            self.anim = 'boulder_left'
        elif self.direction == (0, -1):
            self.anim = 'boulder_up'

        if self.rolling and not self.falling:
            if not self.is_moving:
                tile_sharer = self.share_tile(block.ArrowBlock)
                if tile_sharer:
                    self.direction = tile_sharer.direction
            if not self.move(*self.direction) and not self.is_moving:
                self.reset_pos()

        worldobject.WorldObject.update(self, e, t, dt)

    def draw(self, window):
        self.img = self.level.imgs[self.anim][int(self.frame)]
        window.blit(self.img, (self.x - 32 - self.level.camera_x,
                               self.y - self.img.get_size()[1] + 24
                               - self.level.camera_y))
