# This file is part of ROBOTGAME
#
# ROBOTGAME is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# ROBOTGAME is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# ROBOTGAME.  If not, see <http://www.gnu.org/licenses/>.
#
# ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' '
#
#                         main_menu.py
#                     --------------------
#       date created : Tue Aug 7 2012
#          copyright : (C) 2012 Sakse Dalum
#      maintained by : Sakse Dalum <don_s@hongabar.org>

"""
The main menu.
"""

import os
import pygame

import level1
import game_menu

class MainMenu(object):
    def __init__(self, game, img_dir):
        self.__dict__.update(locals())

        self.load()

    def load(self):
        self.background_img = pygame.image.load(os.path.join(self.img_dir,
                                                             'main_menu.png'))
        self.background_img = pygame.transform.smoothscale(
            self.background_img, self.game.window.get_size())

        self.space_img = pygame.image.load(os.path.join(
                self.img_dir,
                'press_space_to_start.png'))

        screen_size = self.game.window.get_size()
        img_size = self.space_img.get_size()
        factors = (float(img_size[0]) / 1920, float(img_size[1]) / 1280)

        self.space_img = pygame.transform.smoothscale(
            self.space_img,
            (int(screen_size[0]*factors[0]),
             int(screen_size[1]*factors[1])))

    def update(self, e, t, dt):
        for event in e:
            if event.type == pygame.KEYDOWN:
                if event.key == pygame.K_SPACE:
                    self.game.goto_level(1)
                if event.key == pygame.K_ESCAPE:
                    self.game.stop()

    def draw(self, window):
        window.blit(self.background_img, (0, 0))

        screen_size = self.game.window.get_size()
        window.blit(self.space_img,
                    (0, screen_size[1] - self.space_img.get_size()[1]))
